package com.jobs.consumer.feignclient;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;

import java.util.Map;

/**
 * 使用 feign 的步骤如下：
 * 1. 在 SpringBoot 的启动类上，增加 @EnableFeignClients 注解
 * 2. 定义 feign 声明式接口，添加注解 @FeignClient,设置 value 值为【服务提供者的】应用名称
 * 3. 定义接口方法，方法的参数列表和返回值，需要跟服务提供者保持一致，方法名称无所谓
 * 4. 在 ConsumerController 中注入该接口对象，调用接口方法完成远程调用
 */

@FeignClient("PROVIDER-APP")
public interface ProviderAppClient {

    @RequestMapping("/provider/getdata/{id}")
    Map GetProviderData(@PathVariable("id") int id);
}
